==> ites-common-1.0.47-sources.jar: org/example/common/cache/conversion/TypeConversion.java <==
package org.example.common.cache.conversion;

import cn.hutool.core.convert.Convert;
import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.alibaba.fastjson2.JSONValidator;

import java.util.Collection;
import java.util.Objects;

/**
 * 类型转换
 * @author liutao
 * @since 2023/12/10
 */
public class TypeConversion {

    public static <T> boolean isCollectionType(T t){
        return t instanceof Collection;
    }

    public static <T> boolean isSimpleType(T t){
        return isSimpleString(t) || isInt(t) || isLong(t) || isDouble(t) || isFloat(t) || isChar(t) || isBoolean(t) || isShort(t) || isByte(t);
    }

    public static <T> boolean isSimpleString(T t){
        if (Objects.isNull(t) || !isString(t)){
            return false;
        }
        return !isJsonString(t);
    }

    private static <T> boolean isJsonString(T t) {
        try {
            JSON.parseObject(t.toString());
            return true;
        } catch (Exception e) {
            return false;
        }
    }

    public static <T> boolean isString(T t) {
        return t instanceof String;
    }

    public static <T> boolean isByte(T t) {
        return t instanceof Byte;
    }

    public static <T> boolean isShort(T t) {
        return t instanceof Short;
    }

    public static <T> boolean isInt(T t) {
        return t instanceof Integer;
    }

    public static <T> boolean isLong(T t) {
        return t instanceof Long;
    }

    public static <T> boolean isChar(T t) {
        return t instanceof Character;
    }

    public static <T> boolean isFloat(T t) {
        return t instanceof Float;
    }

    public static <T> boolean isDouble(T t) {
        return t instanceof Double;
    }

    public static <T> boolean isBoolean(T t) {
        return t instanceof Boolean;
    }

    public static <T> Class<?> getClassType(T t) {
        return t.getClass();
    }

    public static <R> R convertor(String str, Class<R> type){
        return Convert.convert(type, str);
    }

}

==> ites-common-1.0.60-sources.jar: org/example/common/cache/conversion/TypeConversion.java <==
package org.example.common.cache.conversion;

import cn.hutool.core.convert.Convert;
import org.example.common.util.JsonUtils;

import java.util.Collection;
import java.util.Objects;

/**
 * 类型转换
 * @author liutao
 * @since 2023/12/10
 */
public class TypeConversion {

    public static <T> boolean isCollectionType(T t){
        return t instanceof Collection;
    }

    public static <T> boolean isSimpleType(T t){
        return isSimpleString(t) || isInt(t) || isLong(t) || isDouble(t) || isFloat(t) || isChar(t) || isBoolean(t) || isShort(t) || isByte(t);
    }

    public static <T> boolean isSimpleString(T t){
        if (Objects.isNull(t) || !isString(t)){
            return false;
        }
        return !isJsonString(t);
    }

    private static <T> boolean isJsonString(T t) {
        try {
            JsonUtils.parseMap(t.toString());
            return true;
        } catch (Exception e) {
            return false;
        }
    }

    public static <T> boolean isString(T t) {
        return t instanceof String;
    }

    public static <T> boolean isByte(T t) {
        return t instanceof Byte;
    }

    public static <T> boolean isShort(T t) {
        return t instanceof Short;
    }

    public static <T> boolean isInt(T t) {
        return t instanceof Integer;
    }

    public static <T> boolean isLong(T t) {
        return t instanceof Long;
    }

    public static <T> boolean isChar(T t) {
        return t instanceof Character;
    }

    public static <T> boolean isFloat(T t) {
        return t instanceof Float;
    }

    public static <T> boolean isDouble(T t) {
        return t instanceof Double;
    }

    public static <T> boolean isBoolean(T t) {
        return t instanceof Boolean;
    }

    public static <T> Class<?> getClassType(T t) {
        return t.getClass();
    }

    public static <R> R convertor(String str, Class<R> type){
        return Convert.convert(type, str);
    }

}
